
unit main;

{$IFDEF FPC}{$MODE objfpc}{$H+}{$ENDIF}

interface

uses
  sysutils,
  
  mseglob,
  mseguiglob,
  mseguiintf,
  mseapplication,
  msestat,
  msegui,
  msegraphics,
  msegraphutils,
  mseclasses,
  mseforms,
  msesimplewidgets,
  msemenus,
  msewidgets,
  msetypes,
  
  bgrabitmap,
  bgrabitmaptypes,
  bgragraphics;

type
  tmainfo = class(tmainform)
    pb_normal: tpaintbox;
    bt_draw: tbutton;
    bt_save: tbutton;
    bt_quit: tbutton;
    pb_hover: tpaintbox;
    pb_pushed: tpaintbox;
    lb_version_mse: tlabel;
    lb_version_bgra: tlabel;
    procedure pb_normal_onpaint(const sender: twidget; const acanvas: tcanvas);
    procedure tmainfo_oncreate(const sender: TObject);
    procedure tmainfo_ondestroy(const sender: TObject);
    procedure bt_draw_onexecute(const sender: TObject);
    procedure bt_save_onexecute(const sender: TObject);
    procedure bt_quit_onexecute(const sender: TObject);
    procedure pb_hover_onpaint(const sender: twidget; const acanvas: tcanvas);
    procedure pb_pushed_onpaint(const sender: twidget; const acanvas: tcanvas);
  private
    bmp_normal: tbgrabitmap;
    bmp_hover: tbgrabitmap;
    bmp_pushed: tbgrabitmap;
  end;

var
  mainfo: tmainfo;

implementation

uses
  main_mfm;

procedure tmainfo.pb_normal_onpaint(const sender: twidget; const acanvas: tcanvas);
begin
  bmp_normal.draw(acanvas, 0, 0, false);
end;

procedure tmainfo.tmainfo_oncreate(const sender: TObject);
begin
  lb_version_mse.caption  := unicodeformat('MSEgui %s', [mseguiversiontext]);
  lb_version_bgra.caption := unicodeformat('BGRABitmap %s', [BGRABitmapVersionStr]);

  bmp_normal := tbgrabitmap.create(pb_normal.bounds_cx, pb_normal.bounds_cy);
  bmp_hover  := tbgrabitmap.create(pb_hover.bounds_cx, pb_hover.bounds_cy);
  bmp_pushed := tbgrabitmap.create(pb_pushed.bounds_cx, pb_pushed.bounds_cy);
end;

procedure tmainfo.tmainfo_ondestroy(const sender: TObject);
begin
  bmp_normal.free;
  bmp_hover.free;
  bmp_pushed.free;
end;

procedure tmainfo.bt_draw_onexecute(const sender: TObject);
begin
  bmp_normal.rectangleantialias(4.5, 4.5, 84.5, 84.5, BGRA(255, 0, 0), 9);
  bmp_hover.rectangleantialias(4.5, 4.5, 84.5, 84.5, BGRA(0, 255, 0), 9);
  bmp_pushed.rectangleantialias(4.5, 4.5, 84.5, 84.5, BGRA(0, 0, 255), 9);
  pb_normal.invalidate;
  pb_hover.invalidate;
  pb_pushed.invalidate;
end;

procedure tmainfo.bt_save_onexecute(const sender: TObject);
var
  b: tbgrabitmap;
begin
  with bmp_normal do
  begin
    b := getpart(makerect( 0,  0, 30, 30)); b.savetofile('00.png'); b.free;
    b := getpart(makerect( 0, 30, 30, 30)); b.savetofile('01.png'); b.free;
    b := getpart(makerect( 0, 60, 30, 30)); b.savetofile('02.png'); b.free;
    b := getpart(makerect(30, 60, 30, 30)); b.savetofile('03.png'); b.free;
    b := getpart(makerect(60, 60, 30, 30)); b.savetofile('04.png'); b.free;
    b := getpart(makerect(60, 30, 30, 30)); b.savetofile('05.png'); b.free;
    b := getpart(makerect(60,  0, 30, 30)); b.savetofile('06.png'); b.free;
    b := getpart(makerect(30,  0, 30, 30)); b.savetofile('07.png'); b.free;
  end;
  with bmp_hover do
  begin
    b := getpart(makerect( 0,  0, 30, 30)); b.savetofile('08.png'); b.free;
    b := getpart(makerect( 0, 30, 30, 30)); b.savetofile('09.png'); b.free;
    b := getpart(makerect( 0, 60, 30, 30)); b.savetofile('10.png'); b.free;
    b := getpart(makerect(30, 60, 30, 30)); b.savetofile('11.png'); b.free;
    b := getpart(makerect(60, 60, 30, 30)); b.savetofile('12.png'); b.free;
    b := getpart(makerect(60, 30, 30, 30)); b.savetofile('13.png'); b.free;
    b := getpart(makerect(60,  0, 30, 30)); b.savetofile('14.png'); b.free;
    b := getpart(makerect(30,  0, 30, 30)); b.savetofile('15.png'); b.free;
  end;
  with bmp_pushed do
  begin
    b := getpart(makerect( 0,  0, 30, 30)); b.savetofile('16.png'); b.free;
    b := getpart(makerect( 0, 30, 30, 30)); b.savetofile('17.png'); b.free;
    b := getpart(makerect( 0, 60, 30, 30)); b.savetofile('18.png'); b.free;
    b := getpart(makerect(30, 60, 30, 30)); b.savetofile('19.png'); b.free;
    b := getpart(makerect(60, 60, 30, 30)); b.savetofile('20.png'); b.free;
    b := getpart(makerect(60, 30, 30, 30)); b.savetofile('21.png'); b.free;
    b := getpart(makerect(60,  0, 30, 30)); b.savetofile('22.png'); b.free;
    b := getpart(makerect(30,  0, 30, 30)); b.savetofile('23.png'); b.free;
  end;
end;

procedure tmainfo.bt_quit_onexecute(const sender: TObject);
begin
  close;
end;

procedure tmainfo.pb_hover_onpaint(const sender: twidget; const acanvas: tcanvas);
begin
  bmp_hover.draw(acanvas, 0, 0, false);
end;

procedure tmainfo.pb_pushed_onpaint(const sender: twidget; const acanvas: tcanvas);
begin
  bmp_pushed.draw(acanvas, 0, 0, false);
end;

end.
